@@ -1,4 +1,4 @@
-/* C++ code produced by gperf version 3.0.4 */
+/* C++ code produced by gperf version 3.1 */
 /* Command-line: /usr/bin/gperf --compare-strncmp --switch=1 -D --struct-type libgearman/command.gperf  */
 /* Computed positions: -k'1,$' */
 
@@ -26,7 +26,7 @@
       && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
       && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
 /* The character set is not based on ISO-646.  */
-#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
+#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
 #endif
 
 #line 11 "libgearman/command.gperf"
@@ -120,7 +120,7 @@ static unsigned char gperf_downcase[256] =
 #ifndef GPERF_CASE_MEMCMP
 #define GPERF_CASE_MEMCMP 1
 static int
-gperf_case_memcmp (register const char *s1, register const char *s2, register unsigned int n)
+gperf_case_memcmp (const char *s1, const char *s2, size_t n)
 {
   for (; n > 0;)
     {
@@ -140,13 +140,13 @@ gperf_case_memcmp (register const char *s1, register const char *s2, register un
 class String2gearman_command_t
 {
 private:
-  static inline unsigned int hash (const char *str, unsigned int len);
+  static inline unsigned int hash (const char *str, size_t len);
 public:
-  static const struct gearman_command_string_st *in_word_set (const char *str, unsigned int len);
+  static const struct gearman_command_string_st *in_word_set (const char *str, size_t len);
 };
 
 inline unsigned int
-String2gearman_command_t::hash (register const char *str, register unsigned int len)
+String2gearman_command_t::hash (const char *str, size_t len)
 {
   static const unsigned char asso_values[] =
     {
@@ -177,7 +177,7 @@ String2gearman_command_t::hash (register const char *str, register unsigned int
       74, 74, 74, 74, 74, 74, 74, 74, 74, 74,
       74, 74, 74, 74, 74, 74
     };
-  return len + asso_values[(unsigned char)str[len - 1]] + asso_values[(unsigned char)str[0]];
+  return len + asso_values[static_cast<unsigned char>(str[len - 1])] + asso_values[static_cast<unsigned char>(str[0])];
 }
 
 static const struct gearman_command_string_st gearman_command_string_st[] =
@@ -271,15 +271,15 @@ static const struct gearman_command_string_st gearman_command_string_st[] =
   };
 
 const struct gearman_command_string_st *
-String2gearman_command_t::in_word_set (register const char *str, register unsigned int len)
+String2gearman_command_t::in_word_set (const char *str, size_t len)
 {
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register int key = hash (str, len);
+      unsigned int key = hash (str, len);
 
       if (key <= MAX_HASH_VALUE && key >= MIN_HASH_VALUE)
         {
-          register const struct gearman_command_string_st *resword;
+          const struct gearman_command_string_st *resword;
 
           switch (key - 4)
             {
@@ -588,7 +588,7 @@ String2gearman_command_t::in_word_set (register const char *str, register unsign
           return 0;
         compare:
           {
-            register const char *s = resword->name;
+            const char *s = resword->name;
 
             if ((((unsigned char)*str ^ (unsigned char)*s) & ~32) == 0 && !gperf_case_memcmp (str, s, len))
               return resword;
